Summary: Library providing support for "XML Signature" and "XML Encryption" standards
Name: xmlsec1
Version: 1.2.27
Release: 1
License: MIT
Group: Development/Libraries
Source0: ftp://ftp.aleksey.com/pub/xmlsec/releases/%{name}-%{version}.tar.gz
Source1: ftp://ftp.aleksey.com/pub/xmlsec/releases/%{name}-%{version}.sig
URL: http://www.aleksey.com/xmlsec/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: libxml2-devel >= 2.9.7-1
BuildRequires: libxslt-devel >= 1.1.32-1

Requires: libxml2 >= 2.9.7-1
Requires: libxslt >= 1.1.32-1

%define _libdir64 %{_prefix}/lib64

%description
XML Security Library is a C library based on LibXML2 and OpenSSL.
The library was created with a goal to support major XML security
standards "XML Digital Signature" and "XML Encryption".

The library is available as 32-bit and 64-bit.


%package devel
Summary: Libraries, includes, etc. to develop applications with XML Digital Signatures and XML Encryption support.
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: libxml2-devel >= 2.9.7-1
Requires: libxslt-devel >= 1.1.32-1
Requires: openssl-devel >= 1.0.2o-1
Requires: zlib-devel >= 1.2.3-7

%description devel
Libraries, includes, etc. you can use to develop applications with XML Digital
Signatures and XML Encryption support.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%package openssl
Summary: OpenSSL crypto plugin for XML Security Library
Group: Development/Libraries
BuildRequires: openssl-devel >= 1.0.2o-1
Requires: %{name} = %{version}
Requires: libxml2 >= 2.9.7-1
Requires: libxslt >= 1.1.32-1
Requires: openssl >= 1.0.2o-1

%description openssl
OpenSSL plugin for XML Security Library provides OpenSSL based crypto services
for the xmlsec library.

The library is available as 32-bit and 64-bit.


%package openssl-devel
Summary: OpenSSL crypto plugin for XML Security Library
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: %{name}-devel = %{version}
Requires: %{name}-openssl = %{version}
Requires: libxml2-devel >= 2.9.7-1
Requires: libxslt-devel >= 1.1.32-1
Requires: openssl-devel >= 1.0.2o-1
Requires: openssl >= 1.0.2o-1

%description openssl-devel
Libraries, includes, etc. for developing XML Security applications with OpenSSL.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
%setup -q
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CC="xlc_r"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-mscrypto \
    --enable-aes \
    --enable-gost \
    --disable-crypto-dl \
    --disable-apps-crypto-dl \
    --without-nss \
    --without-nspr \
    --without-gcrypt \
    --without-gnutls
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-mscrypto \
    --enable-aes \
    --enable-gost \
    --disable-crypto-dl \
    --disable-apps-crypto-dl \
    --without-nss \
    --without-nspr \
    --without-gcrypt \
    --without-gnutls
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libxmlsec1.a ${RPM_BUILD_ROOT}%{_libdir64}/libxmlsec1.so.1
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libxmlsec1-openssl.a ${RPM_BUILD_ROOT}%{_libdir64}/libxmlsec1-openssl.so.1

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files 
%defattr(-,root,system)
%doc 32bit/AUTHORS 32bit/ChangeLog 32bit/NEWS 32bit/README 32bit/Copyright
%{_bindir}/xmlsec1
%{_bindir}/xmlsec1_64
%{_libdir}/libxmlsec1.a
%{_libdir}/libxmlsec1.so*
%{_libdir64}/libxmlsec1.so*
%{_mandir}/man1/xmlsec1.1*
/usr/bin/xmlsec1
/usr/bin/xmlsec1_64
/usr/lib/libxmlsec1.a
/usr/lib/libxmlsec1.so*
/usr/lib64/libxmlsec1.so*


%files devel
%defattr(-,root,system)  
%doc 32bit/AUTHORS 32bit/ChangeLog 32bit/NEWS 32bit/README 32bit/Copyright
%{_bindir}/xmlsec1-config
%{_bindir}/xmlsec1-config_64
%dir %{_includedir}/%{name}
%dir %{_includedir}/%{name}/xmlsec
%{_includedir}/%{name}/xmlsec/*.h
%dir %{_includedir}/%{name}/xmlsec/private
%{_includedir}/%{name}/xmlsec/private/*
%{_libdir}/libxmlsec1.la
%{_libdir64}/libxmlsec1.la
%{_libdir}/xmlsec1Conf.sh
%{_libdir64}/xmlsec1Conf.sh
%{_libdir}/pkgconfig/xmlsec1.pc
%{_libdir64}/pkgconfig/xmlsec1.pc
%{_mandir}/man1/xmlsec1-config.1*
%{_datadir}/doc/xmlsec1/* 
%{_datadir}/aclocal/*
/usr/bin/xmlsec1-config
/usr/bin/xmlsec1-config_64
/usr/include/%{name}
/usr/lib/libxmlsec1.la
/usr/lib64/libxmlsec1.la
/usr/lib/xmlsec1Conf.sh
/usr/lib64/xmlsec1Conf.sh


%files openssl
%defattr(-,root,system)  
%{_libdir}/libxmlsec1-openssl.a
%{_libdir}/libxmlsec1-openssl.so*
%{_libdir64}/libxmlsec1-openssl.so*
/usr/lib/libxmlsec1-openssl.a
/usr/lib/libxmlsec1-openssl.so*
/usr/lib64/libxmlsec1-openssl.so*


%files openssl-devel
%defattr(-,root,system)  
%dir %{_includedir}/%{name}/xmlsec/openssl
%{_includedir}/%{name}/xmlsec/openssl/*
%{_libdir}/libxmlsec1-openssl.la
%{_libdir64}/libxmlsec1-openssl.la
%{_libdir}/pkgconfig/xmlsec1-openssl.pc
%{_libdir64}/pkgconfig/xmlsec1-openssl.pc
/usr/lib/libxmlsec1-openssl.la
/usr/lib64/libxmlsec1-openssl.la


%changelog
* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.27-1
- updated to version 1.2.27

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.26-1
- updated to version 1.2.26

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.25-1
- updated to version 1.2.25

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.24-1
- updated to version 1.2.24

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.23-1
- updated to version 1.2.23

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.22-1
- updated to version 1.2.22

* Mon Oct 29 2018 Michael Perzl <michael@perzl.org> - 1.2.21-1
- updated to version 1.2.21
- added RTL-style shared members

* Wed Nov 16 2016 Michael Perzl <michael@perzl.org> - 1.2.20-3
- recompiled against latest versions

* Fri Mar 04 2016 Michael Perzl <michael@perzl.org> - 1.2.20-2
- recompiled against latest versions

* Fri Aug 15 2014 Michael Perzl <michael@perzl.org> - 1.2.20-1
- updated to version 1.2.20

* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 1.2.19-1
- updated to version 1.2.19

* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 1.2.18-2
- rebuilt against OpenSSL version 1.0.1

* Thu Sep 22 2011 Michael Perzl <michael@perzl.org> - 1.2.18-1
- updated to version 1.2.18

* Wed May 26 2010 Michael Perzl <michael@perzl.org> - 1.2.12-1
- first version for AIX V5.1 and higher
